@@ -8,12 +8,11 @@ import pandas
 import matplotlib.pyplot as plt
 import plotly.tools as tls
 import numpy as np
-from IPython.display import HTML, display
 from transcriptic.util import humanize
 from transcriptic import dataset as get_dataset
 
 
-class PlateRead(object):
+class _PlateRead(object):
 
     """
     A PlateRead object generalizes the parsing of datasets derived from the
@@ -30,9 +29,6 @@ class PlateRead(object):
         self.dataset = dataset
         self.control_reading = control_reading
         self.op_type = op_type
-        if ("data_keys" not in self.dataset.attributes or
-                len(self.dataset.attributes["data_keys"]) == 0):
-            raise RuntimeError("No data found in given dataset.")
         if self.op_type not in ["absorbance", "fluorescence", "luminescence"]:
             raise RuntimeError(
                 "Data given is not from a spectrophotometry operation.")
@@ -69,7 +65,7 @@ class PlateRead(object):
         self.params["plate"] = plate_info_dict
 
         # Get dataset and parse into DataFrame
-        data_dict = get_dataset(self.dataset.attributes["id"]).attributes
+        data_dict = get_dataset(self.dataset.attributes["id"])
         df_dict = {}
         well_count = self.dataset.attributes[
             "container"]["container_type"]["well_count"]
@@ -165,7 +161,7 @@ class PlateRead(object):
             return py.iplot(pyfig)
 
 
-class Absorbance(PlateRead):
+class Absorbance(_PlateRead):
 
     """
     An Absorbance object parses a dataset object and provides functions for
@@ -191,8 +187,8 @@ class Absorbance(PlateRead):
 
     def __init__(self, dataset, group_labels, group_wells=None,
                  control_abs=None, name=None):
-        PlateRead.__init__(self, "absorbance", dataset, group_labels,
-                           group_wells, control_abs, name)
+        _PlateRead.__init__(self, "absorbance", dataset, group_labels,
+                            group_wells, control_abs, name)
 
     def beers_law(self, conc_list=None, use_adj=True, **kwargs):
         """"
@@ -249,7 +245,7 @@ class Absorbance(PlateRead):
             print("%s R^2: %s" % (self.name, (1-old_div(ss_res, ss_tot))))
 
 
-class Fluorescence(PlateRead):
+class Fluorescence(_PlateRead):
 
     """
     An Fluorescence object parses a dataset object and provides functions for
@@ -275,11 +271,11 @@ class Fluorescence(PlateRead):
 
     def __init__(self, dataset, group_labels, group_wells=None,
                  control_fluor=None, name=None):
-        PlateRead.__init__(self, "fluorescence", dataset, group_labels,
-                           group_wells, control_fluor, name)
+        _PlateRead.__init__(self, "fluorescence", dataset, group_labels,
+                            group_wells, control_fluor, name)
 
 
-class Luminescence(PlateRead):
+class Luminescence(_PlateRead):
 
     """
     An Luminescence object parses a dataset object and provides functions for
@@ -305,8 +301,8 @@ class Luminescence(PlateRead):
 
     def __init__(self, dataset, group_labels, group_wells=None,
                  control_lumi=None, name=None):
-        PlateRead.__init__(self, "luminescence", dataset, group_labels,
-                           group_wells, control_lumi, name)
+        _PlateRead.__init__(self, "luminescence", dataset, group_labels,
+                            group_wells, control_lumi, name)
 
 
 def compare_standards(pr_obj, std_pr_obj):
@@ -319,9 +315,9 @@ def compare_standards(pr_obj, std_pr_obj):
     Parameters
     ----------
 
-    pr_obj: PlateRead
+    pr_obj: _PlateRead
         Sample plate read object
-    std_pr_obj: PlateRead
+    std_pr_obj: _PlateRead
         Standard plate read object
     """
     # Compare against mean of standard absorbance
@@ -342,8 +338,15 @@ def compare_standards(pr_obj, std_pr_obj):
         pr_obj.df.var(), columns=["Sample Variance"])
     sampleCV = pandas.DataFrame(pr_obj.cv, columns=["Sample (%) CV"])
 
-    if pr_obj.name:
-        display(HTML("<b>Standards Comparison (%s)</b>" % pr_obj.name))
-    print(sampleVariance)
-    print(sampleCV)
-    print(RMSE)
+    try:
+        from IPython.display import HTML, display
+        if pr_obj.name:
+            display(HTML("<b>Standards Comparison (%s)</b>" % pr_obj.name))
+        display(sampleVariance)
+        display(sampleCV)
+        display(RMSE)
+    except:
+        # If IPython module is not present or unable to show, print results
+        print(sampleVariance)
+        print(sampleCV)
+        print(RMSE)
